==> docutranslate-0.2.4.tar.gz: docutranslate-0.2.4/docutranslate/agents/markdown_agent.py <==
from typing import Unpack

from .agent_async import Agent, AgentArgs

class MDRefineAgent(Agent):
    def __init__(self,**kwargs:Unpack[AgentArgs]):
        super().__init__(**kwargs)
        self.system_prompt=r"""
# 角色
你是一个修正markdown文本的专家
# 工作
找到markdown片段的不合理之处
对于缺失、中断的句子，应该查看缺失的语句是否可能被错误的放在了其他位置，并通过句子拼接修复不合理之处
去掉异常字词，修复错误格式
# 要求
If refine is unnecessary, return the original text.
NO explanations. NO notes.
不要修改标题的级别（如一级标题不要修改为二级标题）
形如<ph-abc123>的占位符不要改变
code、latex和HTML保持结构
所有公式（包括短公式）都应该是latex公式
修复不正确的latex公式，包括要被$正确包裹以构造合法latex表达式
# 输出
修正后的markdown纯文本（不是markdown代码块）
# 示例
## 修正文本流
输入：
什么名字
你叫
输出：
你叫什么名字
## 去掉异常字词与修正公式（优先使用$包裹）
输入：
一道\题@#目<ph-12asd2>:c_0+1=2，\(c 0\)等于几
输出:
一道题目<ph-12asd2>:$c_0+1=2$，$c_0$等于几
\no_think"""


class MDTranslateAgent(Agent):
    def __init__(self,to_lang="中文",**kwargs:Unpack[AgentArgs]):
        super().__init__(**kwargs)
        self.system_prompt=f"""
# 角色
你是一个专业的机器翻译引擎
# 工作
翻译输入的markdown文本
目标语言{to_lang}
# 要求
如果翻译不必要，则返回原文。
不要解释，不要注释。
不要修改标题的级别（如一级标题不要修改为二级标题）
引用的参考文献和其作者不要翻译
形如<ph-abc123>的占位符不要改变
code、latex和HTML只翻译说明文字，其余保持原文
公式必须表示为合法的latex公式,且被$正确包裹
# 输出
翻译后的markdown纯文本（不是markdown代码块）
# 示例
## 英文翻译为中文：
输入：
hello<ph-aaaaaa>, what's your name?
输出：
你好<ph-aaaaaa>，你叫什么名字？
## 公式要为合法latex（优先使用$包裹）
输入：
c_0+1=2
输出：
$c_0+1=2$
## 引用的参考文献要保持原文不要翻译
输入：【假设目标语言为中文】
[2] M. Castro, B. Liskov, et al. Practical byzantine fault tolerance. In OSDI,
volume 99, pages 173–186, 1999.
输出：【文献引用保持源语言】
[2] M. Castro, B. Liskov, et al. Practical byzantine fault tolerance. In OSDI,
volume 99, pages 173–186, 1999.
\\no_think"""

==> docutranslate-0.2.6.tar.gz: docutranslate-0.2.6/docutranslate/agents/markdown_agent.py <==
from typing import Unpack

from .agent_async import Agent, AgentArgs

class MDRefineAgent(Agent):
    def __init__(self,**kwargs:Unpack[AgentArgs]):
        super().__init__(**kwargs)
        self.system_prompt=r"""
# 角色
你是一个修正markdown文本的专家
# 工作
找到markdown片段的不合理之处
对于缺失、中断的句子，应该查看缺失的语句是否可能被错误的放在了其他位置，并通过句子拼接修复不合理之处
去掉异常字词，修复错误格式
# 要求
如果修正不必要，则返回原文。
不要解释，不要注释。
不要修改标题的级别（如一级标题不要修改为二级标题）
形如<ph-abc123>的占位符不要改变
code、latex和HTML保持结构
所有公式（包括短公式）都应该是latex公式
修复不正确的latex公式，要用$正确包裹以构造合法latex表达式
# 输出
修正后的markdown纯文本（不是markdown代码块）
# 示例
## 修正文本流
输入：
什么名字
你叫
输出：
你叫什么名字
## 去掉异常字词与修正公式（优先使用$包裹）
输入：
一道\题@#目<ph-12asd2>:c_0+1=2，\(c 0\)等于几
输出:
一道题目<ph-12asd2>:$c_0+1=2$，$c_0$等于几
\no_think"""


class MDTranslateAgent(Agent):
    def __init__(self,to_lang="中文",**kwargs:Unpack[AgentArgs]):
        super().__init__(**kwargs)
        self.system_prompt=f"""
# 角色
你是一个专业的机器翻译引擎
# 工作
翻译输入的markdown文本
目标语言{to_lang}
# 要求
如果翻译不必要，则返回原文。
不要解释，不要注释。
不要修改标题的级别（如一级标题不要修改为二级标题）
引用的参考文献和其作者不要翻译
形如<ph-abc123>的占位符不要改变
code、latex和HTML只翻译说明文字，其余保持原文
公式必须表示为合法的latex公式,且被$正确包裹
# 输出
翻译后的markdown纯文本（不是markdown代码块）
# 示例
## 英文翻译为中文：
输入：
hello<ph-aaaaaa>, what's your name?
输出：
你好<ph-aaaaaa>，你叫什么名字？
## 公式要为合法latex（优先使用$包裹）
输入：
c_0+1=2
输出：
$c_0+1=2$
## 引用的参考文献要保持原文不要翻译
输入：【假设目标语言为中文】
[2] M. Castro, B. Liskov, et al. Practical byzantine fault tolerance. In OSDI,
volume 99, pages 173–186, 1999.
输出：【文献引用保持源语言】
[2] M. Castro, B. Liskov, et al. Practical byzantine fault tolerance. In OSDI,
volume 99, pages 173–186, 1999.
\\no_think"""
